@@ -9,6 +9,31 @@ import inspect
 import pprint
 
 
+def getLegacyEntity(user, entityClass, id):
+    """
+    *** LEGACY ***
+    Parameters
+    ----------
+    user (obj)
+        The Labstep user.
+    entityClass (class)
+        The Class of entity to retrieve.
+    id (int)
+        The id of the entity.
+
+    Returns
+    -------
+    entity
+        An object representing a Labstep Entity.
+    """
+    headers = getHeaders(user)
+    url = url_join(API_ROOT, "/api/generic/",
+                   entityClass.__entityName__, str(id))
+    r = requests.get(url, headers=headers)
+    handleError(r)
+    return entityClass(json.loads(r.content), user)
+
+
 def getEntity(user, entityClass, id, isDeleted='both'):
     """
     Parameters
@@ -27,16 +52,19 @@ def getEntity(user, entityClass, id, isDeleted='both'):
     entity
         An object representing a Labstep Entity.
     """
-    params = {'is_deleted': isDeleted,
-              'get_single': 1,
-              'id': id
-              }
-    headers = getHeaders(user)
-    url = url_join(API_ROOT, "/api/generic/",
-                   entityClass.__entityName__)
-    r = requests.get(url, headers=headers, params=params)
-    handleError(r)
-    return entityClass(json.loads(r.content), user)
+    if hasattr(entityClass, '__isLegacy__'):
+        return getLegacyEntity(user, entityClass, id)
+    else:
+        params = {'is_deleted': isDeleted,
+                  'get_single': 1,
+                  'id': id
+                  }
+        headers = getHeaders(user)
+        url = url_join(API_ROOT, "/api/generic/",
+                       entityClass.__entityName__)
+        r = requests.get(url, headers=headers, params=params)
+        handleError(r)
+        return entityClass(json.loads(r.content), user)
 
 
 def getEntities(user, entityClass, count, filterParams={}):
